diff --git a/templates/index.html b/templates/index.html
index 02bdb38..dcc54f1 100644
--- a/templates/index.html
+++ b/templates/index.html
@@ -471,23 +471,23 @@
- 50
+ 25
- 200
+ 175
diff --git a/static/js/main.js b/static/js/main.js
index f339090..7fc07a5 100644
--- a/static/js/main.js
+++ b/static/js/main.js
@@ -343,7 +343,7 @@
/**
* Apply zoom transformation to CV paper
* @param {number} zoomValue - Zoom percentage (50-200)
* @param {boolean} saveToStorage - Whether to persist to localStorage
*/
function applyZoom(zoomValue, saveToStorage = true) {
@@ -410,7 +410,7 @@
if (!slider) return;
const currentZoom = parseInt(slider.value, 10);
- const newZoom = Math.min(200, Math.max(50, currentZoom + step));
+ const newZoom = Math.min(175, Math.max(25, currentZoom + step));
slider.value = newZoom;
applyZoom(newZoom, true);
@@ -343,7 +343,7 @@
/**
* Apply zoom transformation to CV paper
- * @param {number} zoomValue - Zoom percentage (50-200)
+ * @param {number} zoomValue - Zoom percentage (25-175, centered at 100)
* @param {boolean} saveToStorage - Whether to persist to localStorage
*/